This is an example program that accompanies pyglet (http://www.pyglet.org).
To build the installer, run:

    pynsist installer.cfg

The source code is licensed under the BSD license, which is quite permissive
(see the source header for details).

The tennis ball image is public domain from openclipart:
https://openclipart.org/detail/139615/tennis-ball

The sound effect was made using www.bfxr.net, and is released to the public domain.
